netapp_ontap.models.ipv6_interface_and_gateway API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ipv6_interface_and_gateway`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class Ipv6InterfaceAndGatewaySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Ipv6InterfaceAndGateway object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `address GET POST PATCH`

    IPv6 address

    Example: fd20:8b1e:b255:5011:10:141:4:97

  `gateway GET POST PATCH`

    The IPv6 address of the default router.

    Example: fd20:8b1e:b255:5011:10::1

  `netmask GET POST PATCH`

    The IPv6 netmask/prefix length. The default value is 64 with a valid range of 1 to 127.

    Example: 64